@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2020-2023, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2020-2024, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2025, Ilya Fedin <fedin-ilja2010@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -34,6 +35,10 @@
 #include <QFile>
 #include <QSettings>
 #include <QtDebug>
+#if defined KF_CONFIGCORE_LIB && defined KF_COLORSCHEME_LIB
+#include <KSharedConfig>
+#include <KColorScheme>
+#endif
 #include "qt6ct.h"
 
 #ifndef QT6CT_DATADIR
@@ -116,6 +121,9 @@ QStringList Qt6CT::sharedColorSchemePaths()
     for(const QString &p : QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation))
     {
         paths << (p + QLatin1String("/qt6ct/colors"));
+#if defined KF_CONFIGCORE_LIB && defined KF_COLORSCHEME_LIB
+        paths << (p + QLatin1String("/color-schemes"));
+#endif
     }
     paths << QLatin1String(QT6CT_DATADIR"/qt6ct/colors");
     paths.removeDuplicates();
@@ -124,6 +132,9 @@ QStringList Qt6CT::sharedColorSchemePaths()
 
 QString Qt6CT::resolvePath(const QString &path)
 {
+    if(path.isEmpty())
+        return path;
+
     QString tmp = path;
     tmp.replace("~", QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
     if(!tmp.contains("$"))
@@ -143,9 +154,21 @@ QString Qt6CT::resolvePath(const QString &path)
     return tmp;
 }
 
-QPalette Qt6CT::loadColorScheme(const QString &filePath, const QPalette &fallback)
+bool Qt6CT::isKColorScheme(const QString &filePath)
 {
-    QPalette customPalette;
+    return filePath.toLower().endsWith(".colors");
+}
+
+std::optional<QPalette> Qt6CT::loadColorScheme(const QString &filePath)
+{
+    if(filePath.isEmpty())
+        return std::nullopt;
+
+#if defined KF_CONFIGCORE_LIB && defined KF_COLORSCHEME_LIB
+    if(isKColorScheme(filePath))
+        return KColorScheme::createApplicationPalette(KSharedConfig::openConfig(filePath));
+#endif
+
     QSettings settings(filePath, QSettings::IniFormat);
     settings.beginGroup("ColorScheme");
     QStringList activeColors = settings.value("active_colors").toStringList();
@@ -153,7 +176,6 @@ QPalette Qt6CT::loadColorScheme(const QString &filePath, const QPalette &fallbac
     QStringList disabledColors = settings.value("disabled_colors").toStringList();
     settings.endGroup();
 
-
 #if (QT_VERSION >= QT_VERSION_CHECK(6,6,0))
     if(activeColors.count() == QPalette::Accent)
         activeColors << activeColors.at(QPalette::Highlight);
@@ -163,24 +185,19 @@ QPalette Qt6CT::loadColorScheme(const QString &filePath, const QPalette &fallbac
         disabledColors << disabledColors.at(QPalette::Highlight);
 #endif
 
+    if(activeColors.count() < QPalette::NColorRoles ||
+            inactiveColors.count() < QPalette::NColorRoles ||
+            disabledColors.count() < QPalette::NColorRoles)
+        return std::nullopt;
 
-    if(activeColors.count() >= QPalette::NColorRoles &&
-            inactiveColors.count() >= QPalette::NColorRoles &&
-            disabledColors.count() >= QPalette::NColorRoles)
+    QPalette customPalette;
+    for (int i = 0; i < QPalette::NColorRoles; i++)
     {
-        for (int i = 0; i < QPalette::NColorRoles; i++)
-        {
-            QPalette::ColorRole role = QPalette::ColorRole(i);
-            customPalette.setColor(QPalette::Active, role, QColor(activeColors.at(i)));
-            customPalette.setColor(QPalette::Inactive, role, QColor(inactiveColors.at(i)));
-            customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
-        }
+        QPalette::ColorRole role = QPalette::ColorRole(i);
+        customPalette.setColor(QPalette::Active, role, QColor(activeColors.at(i)));
+        customPalette.setColor(QPalette::Inactive, role, QColor(inactiveColors.at(i)));
+        customPalette.setColor(QPalette::Disabled, role, QColor(disabledColors.at(i)));
     }
-    else
-    {
-        customPalette = fallback; //load fallback palette
-    }
-
     return customPalette;
 }
 
