@@ -1,5 +1,6 @@
 /*
- * Copyright (c) 2020-2023, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2020-2024, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2025, Ilya Fedin <fedin-ilja2010@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -30,7 +31,7 @@
 #define QT6CT_H
 
 #define QT6CT_VERSION_MAJOR 0
-#define QT6CT_VERSION_MINOR 9
+#define QT6CT_VERSION_MINOR 10
 
 #define QT6CT_TOSTRING(s) #s
 #define QT6CT_STRINGIFY(s)         QT6CT_TOSTRING(s)
@@ -67,7 +68,8 @@ public:
     static QString userColorSchemePath();
     static QStringList sharedColorSchemePaths();
     static QString resolvePath(const QString &path);
-    static QPalette loadColorScheme(const QString &filePath, const QPalette &fallback);
+    static bool isKColorScheme(const QString &filePath);
+    static std::optional<QPalette> loadColorScheme(const QString &filePath);
 
     static void registerStyleInstance(StyleInstance *instance);
     static void unregisterStyleInstance(StyleInstance *instance);
