@@ -35,7 +35,7 @@
     </message>
     <message>
         <location filename="../appearancepage.ui" line="124"/>
-        <location filename="../appearancepage.cpp" line="84"/>
+        <location filename="../appearancepage.cpp" line="85"/>
         <source>Default</source>
         <translation>Standaard</translation>
     </message>
@@ -60,27 +60,27 @@
         <translation>Standaard dialoogvensters:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="71"/>
+        <location filename="../appearancepage.cpp" line="72"/>
         <source>Create</source>
         <translation>Maken</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="72"/>
+        <location filename="../appearancepage.cpp" line="73"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="73"/>
+        <location filename="../appearancepage.cpp" line="74"/>
         <source>Create a Copy</source>
         <translation>Kopie maken</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="74"/>
+        <location filename="../appearancepage.cpp" line="75"/>
         <source>Rename</source>
         <translation>Naam wijzigen</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="76"/>
+        <location filename="../appearancepage.cpp" line="77"/>
         <source>Remove</source>
         <translation>Verwijderen</translation>
     </message>
@@ -259,12 +259,12 @@
         <translation>fonts.conf verwijderen</translation>
     </message>
     <message>
-        <location filename="../fontspage.cpp" line="111"/>
+        <location filename="../fontspage.cpp" line="110"/>
         <source>Remove Font Configuration</source>
         <translation>Lettertypeconfiguatie verwijderen</translation>
     </message>
     <message>
-        <location filename="../fontspage.cpp" line="112"/>
+        <location filename="../fontspage.cpp" line="111"/>
         <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
         <translation>Weet je zeker dat je &lt;i&gt;%1&lt;/i&gt; wilt verwijderen?</translation>
     </message>
@@ -463,32 +463,32 @@
         <translation>Versie: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="110"/>
+        <location filename="../mainwindow.cpp" line="111"/>
         <source>Warning</source>
         <translation>Waarschuwing</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="119"/>
+        <location filename="../mainwindow.cpp" line="120"/>
         <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
         <translation>Verwijder de omgevingsvariabel &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; (huidige waarde: &lt;b&gt;%1&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../mainwindow.cpp" line="126"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
         <translation>De &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt;-omgevingsvariabel is niet juist ingesteld. Vereiste waarden: &lt;b&gt;qt6ct&lt;/b&gt; of &lt;b&gt;qt5ct&lt;/b&gt;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="131"/>
         <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
         <translation>De omgevingsvariabel &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; is niet goed ingesteld (huidige waarde: &lt;b&gt;%1&lt;/b&gt; - vereiste waarde: &lt;b&gt;qt6ct&lt;/b&gt; of &lt;b&gt;qt5ct&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="138"/>
         <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
         <translation>&lt;b&gt;libqt6ct-style.so&lt;/b&gt; is niet aangetroffen.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="143"/>
+        <location filename="../mainwindow.cpp" line="144"/>
         <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
         <translation>De plug-in &lt;b&gt;%1&lt;/b&gt; is gebouwd met een incompatibele Qt-versie (%2).</translation>
     </message>
@@ -636,7 +636,12 @@
         <translation>Plaatshoudertekst</translation>
     </message>
     <message>
-        <location filename="../paletteeditdialog.cpp" line="107"/>
+        <location filename="../paletteeditdialog.cpp" line="97"/>
+        <source>Accent</source>
+        <translation>Accentkleur</translation>
+    </message>
+    <message>
+        <location filename="../paletteeditdialog.cpp" line="110"/>
         <source>Select Color</source>
         <translation>Kleur selecteren</translation>
     </message>
@@ -697,7 +702,7 @@
     <message>
         <location filename="../qsspage.ui" line="66"/>
         <location filename="../qsspage.cpp" line="51"/>
-        <location filename="../qsspage.cpp" line="87"/>
+        <location filename="../qsspage.cpp" line="86"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
@@ -719,74 +724,74 @@
         <translation>Kopie maken</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="92"/>
+        <location filename="../qsspage.cpp" line="91"/>
         <source>View</source>
         <translation>Weergave</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="106"/>
-        <location filename="../qsspage.cpp" line="251"/>
+        <location filename="../qsspage.cpp" line="105"/>
+        <location filename="../qsspage.cpp" line="250"/>
         <source>File name:</source>
         <translation>Bestandsnaam:</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="106"/>
-        <location filename="../qsspage.cpp" line="251"/>
+        <location filename="../qsspage.cpp" line="105"/>
+        <location filename="../qsspage.cpp" line="250"/>
         <source>Enter Style Sheet Name</source>
         <translation>Geef dit stijlblad een naam</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="117"/>
-        <location filename="../qsspage.cpp" line="218"/>
-        <location filename="../qsspage.cpp" line="226"/>
-        <location filename="../qsspage.cpp" line="263"/>
-        <location filename="../qsspage.cpp" line="271"/>
+        <location filename="../qsspage.cpp" line="116"/>
+        <location filename="../qsspage.cpp" line="217"/>
+        <location filename="../qsspage.cpp" line="225"/>
+        <location filename="../qsspage.cpp" line="262"/>
+        <location filename="../qsspage.cpp" line="270"/>
         <source>Error</source>
         <translation>Foutmelding</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="117"/>
+        <location filename="../qsspage.cpp" line="116"/>
         <source>The file &quot;%1&quot; already exists</source>
         <translation>Het bestand “%1” bestaat al</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="151"/>
+        <location filename="../qsspage.cpp" line="150"/>
         <source>Confirm Remove</source>
         <translation>Verwijderen bevestigen</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="152"/>
+        <location filename="../qsspage.cpp" line="151"/>
         <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
         <translation>Weet je zeker dat je het stijlblad “%1” wilt verwijderen?</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="208"/>
+        <location filename="../qsspage.cpp" line="207"/>
         <source>Rename Style Sheet</source>
         <translation>Stijlbladnaam wijzigen</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="208"/>
+        <location filename="../qsspage.cpp" line="207"/>
         <source>Style sheet name:</source>
         <translation>Stijlbladnaam:</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="218"/>
-        <location filename="../qsspage.cpp" line="263"/>
+        <location filename="../qsspage.cpp" line="217"/>
+        <location filename="../qsspage.cpp" line="262"/>
         <source>The style sheet &quot;%1&quot; already exists</source>
         <translation>Het stijlblad “%1” bestaat al</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="226"/>
+        <location filename="../qsspage.cpp" line="225"/>
         <source>Unable to rename file</source>
         <translation>De bestandsnaam kan niet worden gewijzigd</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="253"/>
+        <location filename="../qsspage.cpp" line="252"/>
         <source>%1 (copy).qss</source>
         <translation>%1 (kopie).qss</translation>
     </message>
     <message>
-        <location filename="../qsspage.cpp" line="271"/>
+        <location filename="../qsspage.cpp" line="270"/>
         <source>Unable to copy file</source>
         <translation>Het bestand kan niet worden gekopieerd</translation>
     </message>
@@ -824,12 +829,12 @@
         <translation>Rooster afdwingen</translation>
     </message>
     <message>
-        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <location filename="../troubleshootingpage.cpp" line="63"/>
         <source>Select Application</source>
         <translation>Kies een programma</translation>
     </message>
     <message>
-        <location filename="../troubleshootingpage.cpp" line="64"/>
+        <location filename="../troubleshootingpage.cpp" line="63"/>
         <source>Executable files (*)</source>
         <translation>Uitvoerbare bestanden (*)</translation>
     </message>
